<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1" xmlns:mifVoc="urn:hl7-org:v3/mif" xmlns:xs="http://www.w3.org/2001/XMLSchema">
	<xsl:output method="xml" encoding="utf-8" indent="yes"/>
	<xsl:key name="valueSet" match="mifVoc:valueSet" use="@valueSetId"/>
	<xsl:variable name="filenamePrefix" select="'Mif_DEFN_VO_VC_Universal_0_'"/>
	<xsl:variable name="strucDomains">
		<domain name="ActRelationshipType"/>
		<domain name="EntityClass"/>
		<domain name="EntityDeterminer"/>
		<domain name="ParticipationType"/>
		<domain name="RoleClass"/>
		<domain name="RoleLinkType"/>
		<domain name="ActClass"/>
		<domain name="ActMood"/>
		<domain name="ActContextLevel"/>
		<domain name="ContextControl"/>
		<domain name="RoleStatus"/>
		<domain name="EntityStatus"/>
	</xsl:variable>

	<xsl:template match="/">
		<xs:schema xmlns="urn:hl7-org:v3">
		<xsl:attribute name="targetNamespace">
			<xsl:text>urn:hl7-org:v3</xsl:text>
		</xsl:attribute>
			<!--
	element foo is just for testing purposes
  -->
			<xs:element name="foo"/>
			<!--
	include hl7:cs so that we don't have to include datatypes.xsd
	just for testing purposes
  -->
			<xs:simpleType name="cs">
				<xs:restriction base="xs:string"/>
			</xs:simpleType>
			   	<xs:simpleType name="Classes">
		<xs:restriction base="cs"/>
	</xs:simpleType>
		<!-- apply templates on all valueSets for structural domains in $strucDomains -->
			<xsl:apply-templates select="/mifVoc:vocabularyModel/mifVoc:valueSet[@name=$strucDomains/domain/@name]"/>
		</xs:schema>
	</xsl:template>

	<!-- output simpleType definitions for coded domains and domains with sub domains -->
	<xsl:template match="mifVoc:valueSet">
		<xs:simpleType name="{@name}_X">
			<xs:restriction base="cs">
				<xsl:for-each select="mifVoc:referencedCode[@isHeadCode='false']">
					<xs:enumeration value="{@conceptCode}"/>
				</xsl:for-each>
			</xs:restriction>
		</xs:simpleType>

			<xs:simpleType name="{@name}">
				<xs:annotation>
					<xs:documentation>
						<xsl:value-of select="mifVoc:annotations/mifVoc:text"/>
					</xs:documentation>
				</xs:annotation>
				<xs:union>
					<xsl:attribute name="memberTypes">
						<xsl:value-of select="@name"/><xsl:text>_X </xsl:text>
						<xsl:for-each select="mifVoc:referencedValueSet">
							<xsl:value-of select="@name"/>
							<xsl:if test="position() != last()">
								<xsl:text> </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:attribute>
				</xs:union>
			</xs:simpleType>
		<xsl:apply-templates select="key('valueSet', mifVoc:referencedValueSet/@valueSetId)"/>
	</xsl:template>
	
	
	<xsl:template match="text()"/>
</xsl:transform>
